@@ -55,10 +55,12 @@ class Printing:
                     description,
                 )
             console.print(to_out, table)
-        else:
+        
+        if not text["Regexes"] and not text["Language"]
             console.print(
                 "[bold #D7Afff]Could not find anything of interest.[/bold #D7Afff]"
             )
+        
         """
         # This is commented out because there's too many possible hash idenfications
         # This is fixed by https://github.com/HashPals/Name-That-Hash/issues/89
